@@ -1,12 +1,13 @@
 package Bio::MUST::Core::Taxonomy::Classifier;
 # ABSTRACT: Helper class for multiple-criterion classifier based on taxonomy
-$Bio::MUST::Core::Taxonomy::Classifier::VERSION = '0.181000';
+$Bio::MUST::Core::Taxonomy::Classifier::VERSION = '0.181120';
 use Moose;
 use namespace::autoclean;
 
 use Bio::MUST::Core::Types;
 use aliased 'Bio::MUST::Core::IdList';
 
+
 has 'categories' => (
     traits   => ['Array'],
     is       => 'ro',
@@ -19,6 +20,13 @@ has 'categories' => (
 
 
 
+sub all_labels {
+    my $self = shift;
+    return map { $_->label } $self->all_categories;
+}
+
+
+
 sub classify {
     my $self     = shift;
     my $listable = shift;
@@ -46,7 +54,7 @@ Bio::MUST::Core::Taxonomy::Classifier - Helper class for multiple-criterion clas
 
 =head1 VERSION
 
-version 0.181000
+version 0.181120
 
 =head1 SYNOPSIS
 
@@ -58,6 +66,8 @@ version 0.181000
 
 =head1 METHODS
 
+=head2 all_labels
+
 =head2 classify
 
 =head1 AUTHOR
